// Represents the data that we repeatedly put on the SPI bus
pub const LEN: usize = 7;

#[derive(Copy, Clone, Debug)]
pub struct SpiData {
    temp: f32,
    free_space: bool,
}

impl SpiData {
    pub fn new(temp: f32, free_space: bool) -> Self {
        Self { temp, free_space }
    }

    pub fn set_temp(&mut self, temp: f32) {
        self.temp = temp
    }

    pub fn set_free(&mut self, free_space: bool) {
        self.free_space = free_space;
    }

    pub fn free_space(&self) -> bool {
        self.free_space
    }
}

// There's probably a better way to do this
// if the temp happens to have some 0xE5 or 0xAA/0x55 in there, it might be possible to cause problems?
// could just use 7 bits per byte and have the extra bit cleared in the data, and set in the pre/post-amble
impl From<SpiData> for [u8; LEN] {
    fn from(data: SpiData) -> Self {
        let free = if data.free_space { 0xAA } else { 0x55 };

        let temp = data.temp.to_le_bytes();

        let mut out = [0xE5, free, 0, 0, 0, 0, 0xE5];

        out[2..6].copy_from_slice(&temp);

        out
    }
}
